import React, { useMemo } from 'react';
import { View } from 'react-native';
import { useMemoStyles } from '@react-native-cask-ui/theme';
const Flex = React.memo(props => {
    const { children, row, around, between, evenly, fill, hStart, vStart, hCenter, vCenter, hEnd, vEnd, wrap, backgroundColor, width, height, minWidth, minHeight, padding, paddingTop, paddingRight, paddingBottom, paddingLeft, paddingVertical, paddingHorizontal, } = props;
    const fillStyle = fill ? { flex: 1 } : {};
    let spread = 'flex-start';
    if (around)
        spread = 'space-around';
    if (between)
        spread = 'space-between';
    if (evenly)
        spread = 'space-evenly';
    let justifyContent = spread;
    let alignItems = 'stretch';
    if (row) {
        // horizontal
        if (hStart)
            justifyContent = 'flex-start';
        if (hCenter)
            justifyContent = 'center';
        if (hEnd)
            justifyContent = 'flex-end';
        if (vStart)
            alignItems = 'flex-start';
        if (vCenter)
            alignItems = 'center';
        if (vEnd)
            alignItems = 'flex-end';
    }
    else {
        // vertical
        if (vStart)
            justifyContent = 'flex-start';
        if (vCenter)
            justifyContent = 'center';
        if (vEnd)
            justifyContent = 'flex-end';
        if (hStart)
            alignItems = 'flex-start';
        if (hCenter)
            alignItems = 'center';
        if (hEnd)
            alignItems = 'flex-end';
    }
    const flexDirection = row ? 'row' : 'column';
    const flexWrap = wrap ? 'wrap' : 'nowrap';
    const layoutStyle = useMemo(() => ({
        flexDirection,
        justifyContent,
        alignItems,
        flexWrap,
        backgroundColor,
        width,
        height,
        minWidth,
        minHeight,
        padding,
        paddingTop,
        paddingRight,
        paddingBottom,
        paddingLeft,
        paddingVertical,
        paddingHorizontal,
    }), [
        flexDirection,
        justifyContent,
        alignItems,
        flexWrap,
        backgroundColor,
        width,
        height,
        minWidth,
        minHeight,
        padding,
        paddingTop,
        paddingRight,
        paddingBottom,
        paddingLeft,
        paddingVertical,
        paddingHorizontal,
    ]);
    const finalStyle = useMemoStyles([fillStyle, layoutStyle]);
    return <View style={finalStyle}>{children}</View>;
});
const FlexWithStatic = Flex;
FlexWithStatic.Row = React.memo(props => {
    const { children, ...otherProps } = props;
    return (<Flex {...otherProps} row>
      {children}
    </Flex>);
});
export default FlexWithStatic;
