import React, { useMemo } from 'react';
import { View } from 'react-native';
const Stack = React.memo(props => {
    const { row, fill, flexes, spacing, children } = props;
    const items = useMemo(() => children
        .filter(item => !!item)
        .map((item, index) => {
        const key = `${index}`;
        let flex;
        if (fill) {
            if (!flexes)
                flex = 1;
            else {
                flex = flexes?.[index] || undefined;
            }
        }
        const flexDirection = row ? 'row' : 'column';
        const style = {
            flex,
            flexDirection,
            marginTop: 0,
            marginLeft: 0,
            marginRight: 0,
            marginBottom: 0,
            [row ? 'marginRight' : 'marginBottom']: index !== children.length - 1 ? spacing : undefined,
        };
        return (<View key={key} style={style}>
              {item}
            </View>);
    }), [row, fill, flexes, spacing, children]);
    return <View style={{ flexDirection: row ? 'row' : 'column', flex: fill ? 1 : undefined }}>{items}</View>;
});
const StackWithStatic = Stack;
StackWithStatic.Row = React.memo(props => {
    const { children, ...otherProps } = props;
    return (<Stack {...otherProps} row>
      {children}
    </Stack>);
});
export default StackWithStatic;
