import React from 'react';
import { StyleSheet, View, Text, TextInput as OriginTextInput, } from 'react-native';
import { useOverride, useMemoStyles } from '@react-native-cask-ui/theme';
const defaultStyles = StyleSheet.create({
    root: {
        flex: 1,
    },
    label: {
        fontSize: 14,
        lineHeight: 19,
        paddingHorizontal: 8,
        paddingBottom: 4,
    },
    textInput: {
        flex: 1,
        height: 40,
        fontSize: 16,
        lineHeight: 21,
        paddingHorizontal: 12,
        color: 'black',
    },
    textInputDisabled: {},
});
const TextInput = React.forwardRef((props, ref) => {
    const { props: overridedProps, styles } = useOverride('TextInput', props);
    const { label, editable, ...otherProps } = overridedProps;
    const finalStyle = useMemoStyles([defaultStyles.root, styles.root]);
    const finalLabelStyle = useMemoStyles([defaultStyles.label, styles.label]);
    const finalTextInputDisabledStyle = useMemoStyles([defaultStyles.textInputDisabled, styles.textInputDisabled]);
    const finalTextInputStyle = useMemoStyles([
        defaultStyles.textInput,
        styles.textInput,
        !editable ? finalTextInputDisabledStyle : null,
    ]);
    return (<View style={finalStyle}>
      {label && <Text style={finalLabelStyle}>{label}</Text>}
      <OriginTextInput ref={ref} placeholderTextColor="#00000033" style={finalTextInputStyle} editable={editable} {...otherProps}/>
    </View>);
});
export default React.memo(TextInput);
